#
# spec file for package soapy-osmo
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with mod_freesrp
#
%define sover 0
%define soapy_modver 0.8
Name:           soapy-osmo
Version:        0.2.5
Release:        8.14
Summary:        Soapy SDR plugins for Osmo supported SDR devices
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            https://github.com/pothosware/SoapyOsmo/wiki
#Git-Clone:     https://github.com/pothosware/SoapyOsmo.git
Source:         https://github.com/pothosware/SoapyOsmo/archive/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         soapy_osmosdr_rfspace_disable.patch
BuildRequires:  cmake
%if 0%{with mod_freesrp}
BuildRequires:  freesrp-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SoapySDR)
BuildRequires:  pkgconfig(libmirisdr)
BuildRequires:  pkgconfig(libosmosdr)

%description
Soapy Osmo - Osmo SDR module
Soapy SDR plugins for OsmoSDR devices

%package -n libSoapyOsmoSDR%{sover}
Summary:        Soapy SDR plugins for Osmo supported SDR devices
Group:          System/Libraries

%description -n libSoapyOsmoSDR%{sover}
Soapy Osmo - Osmo SDR module
Soapy SDR plugins for OsmoSDR devices

%package devel
Summary:        Development files for the SoapyOsmoSDR library
Group:          Development/Libraries/C and C++
Requires:       libSoapyOsmoSDR%{sover} = %{version}

%description devel
This subpackage contains libraries and header files for developing
applications that want to make use of libSoapyOsmoSDR.

%package -n soapysdr%{soapy_modver}-module-mirisdr
Summary:        SoapySDR mirisdr module
Group:          System/Libraries

%description -n soapysdr%{soapy_modver}-module-mirisdr
Soapy mirisdr - mirisdr device support for Soapy SDR.
A Soapy module that supports Mirics SDR devices within the Soapy API.

%package -n soapysdr%{soapy_modver}-module-osmosdr
Summary:        SoapySDR osmosdr module
Group:          System/Libraries

%description -n soapysdr%{soapy_modver}-module-osmosdr
Soapy OsmoSDR - OsmoSDR device support for Soapy SDR.
A Soapy module that supports OsmoSDR devices within the Soapy API.

%if 0%{with mod_freesrp}
%package -n soapysdr%{soapy_modver}-module-freesrp
Summary:        FreeSRP osmosdr module
Group:          System/Libraries

%description -n soapysdr%{soapy_modver}-module-freesrp
Soapy FreeSRP - FreeSRP device support for Soapy SDR.
A Soapy module that supports FreeSRP devices within the Soapy API.
%endif

%prep
%setup -q -n SoapyOsmo-%{name}-%{version}
%patch0 -p1

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install

%post   -n libSoapyOsmoSDR%{sover} -p /sbin/ldconfig
%postun -n libSoapyOsmoSDR%{sover} -p /sbin/ldconfig

%files -n libSoapyOsmoSDR%{sover}
%license COPYING
%doc Changelog.txt README.md
%{_libdir}/libSoapyOsmoSDR.so.*

%files devel
%{_libdir}/libSoapyOsmoSDR.so

%files -n soapysdr%{soapy_modver}-module-mirisdr
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libmiriSupport.so

%files -n soapysdr%{soapy_modver}-module-osmosdr
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libosmosdrSupport.so

%if 0%{with mod_freesrp}
%files -n soapysdr%{soapy_modver}-module-freesrp
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libfreesrpSupport.so
%endif

%changelog
* Fri Aug 27 2021 Martin Hauke <mardnh@gmx.de>
- Make build with support for FreeSRP optional and disable it
  by default.
* Sat Jul 10 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Fri Nov  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Disable RfSpace module (default with next upstream release),
  deprecated in favor of the separate soapy-netsdr module.
  Circumvents build/linking failures.
  * Add soapy_osmosdr_rfspace_disable.patch
- Drop no longer required soap-osmo-fix-pthread-linking-issue.patch
* Sat Nov 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update soapy-module version 0.6 -> 0.7
* Thu Jun 28 2018 mardnh@gmx.de
- Add patch:
  * soap-osmo-fix-pthread-linking-issue.patch
    (Fix pthread linking issues on Tumbleweed)
* Fri Apr 27 2018 mardnh@gmx.de
- Drop support for the following modules
  * Airspy
  * RTL-SDR
  * HackRF
  * RedPitaya
  Upstream has moved the development of each of these modules to
  it's own repository.
  We already have packages for those.
  * hardware:sdr/soapy-airspy
  * hardware:sdr/soapy-rtlsdr
  * hardware:sdr/soapy-hackrf
  * hardware:sdr/soapy-redpitaya
* Mon Dec 11 2017 mardnh@gmx.de
- Improve boost dependency (fixes build fail on Factory)
* Mon May  8 2017 mardnh@gmx.de
- Build with support for
  * RTL-SDR
  * Airspy
  * HackRF
  * RedPitaya
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.2.5
  * Add support for FreeSRP
  * Added setFrequencyCorrection() and getFrequencyCorrection()
  * Added getBandwidthRange() and getSampleRateRange()
  * Support for optional gain range step in type conversions
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Fri Apr 14 2017 mardnh@gmx.de
- Update to version 0.2.4 (tagged release)
- renamed package from SoapyOsmo to soapy-osmo
- specfile cleanup
* Tue Jan  3 2017 mardnh@gmx.de
- Update to version 0.2.4.git1472790015.1205972:
  * osmo: Update internal copy of gr-osmosdr to 7cec4c0f
  * removed copy of gr-osmosdr in favor of subtree
  * Squashed 'gr-osmosdr/' content from commit 55fe961
  * osmo: Update internal copy of gr-osmosdr to 55fe961
  * osmo:  Fixed write() implementation when sinks use consume()
  * Squashed 'gr-osmosdr/' changes from 55fe961..810a981
  * osmo: Added RedPitaya build support (off by default)
  * updated changelog for 0.2.2 release
  * Squashed 'gr-osmosdr/' changes from 810a981..ac15e78
  * osmo: update script + gr-osmosdr ac15e789
  * Squashed 'gr-osmosdr/' changes from ac15e78..164a09f
  * split up top and debian changelog
  * updated changelog for 0.2.3 release
  * Squashed 'gr-osmosdr/' changes from 164a09f..ae686c4
  * Update internal copy of gr-osmosdr to ae686c46
  * use SoapyAirspy, debian SoapySDR module ABI format
  * debian: fix package to match library name
  * travis: also remove check here for airspy
  * debian: fixed typo in package desc
  * updated changelog for 0.2.4 release
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.2.0.git1448006628.ad82e98:
  + osmo: Implement getStreamFormats() and getNativeStreamFormat()
  + travis: install driver development files from ppa
  + travis: correct comments, miri, osmo, and airspy only
  + travis: add driver load check to unit tests
* Sun Oct 11 2015 mardnh@gmx.de
- initial package
